Optimizers
==========

.. toctree::
  :maxdepth: 1

  Optimization Overview <_autosummary/stko.Optimizer>

.. toctree::
  :maxdepth: 1

  OptimizerSequence <_autosummary/stko.OptimizerSequence>
  TryCatchOptimizer <_autosummary/stko.TryCatchOptimizer>

  Aligner <_autosummary/stko.Aligner>
  Collapser <_autosummary/stko.Collapser>
  CollapserMC <_autosummary/stko.CollapserMC>
  ETKDG <_autosummary/stko.ETKDG>
  UFF <_autosummary/stko.UFF>
  MMFF <_autosummary/stko.MMFF>
  MetalOptimizer <_autosummary/stko.MetalOptimizer>
  OpenBabel <_autosummary/stko.OpenBabel>
  OpenMMForceField <_autosummary/stko.OpenMMForceField>
  OpenMMMD <_autosummary/stko.OpenMMMD>
  GulpUFFOptimizer <_autosummary/stko.GulpUFFOptimizer>
  MacroModelForceField <_autosummary/stko.MacroModelForceField>
  XTB <_autosummary/stko.XTB>
  XTBFF <_autosummary/stko.XTBFF>
  XTBCREST <_autosummary/stko.XTBCREST>
  XTBFFCREST <_autosummary/stko.XTBFFCREST>

  GulpUFFMDOptimizer <_autosummary/stko.GulpUFFMDOptimizer>
  MacroModelMD <_autosummary/stko.MacroModelMD>
